@@ -1,6 +1,7 @@
 import click
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
-from opnsense_cli.callbacks.click import formatter_from_formatter_name, bool_as_string, comma_to_newline
+from opnsense_cli.callbacks.click import \
+    formatter_from_formatter_name, bool_as_string, comma_to_newline, available_formats
 from opnsense_cli.commands.firewall import firewall
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.firewall import FirewallAlias, FirewallAliasUtil
@@ -29,13 +30,13 @@ def alias(ctx, api_client: ApiClient, **kwargs):
     '--output', '-o',
     help='Specifies the Output format.',
     default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="name,type,description,content,enabled",
     show_default=True,
 )
@@ -55,13 +56,13 @@ def list(firewall_alias_svc: FirewallAliasFacade, **kwargs):
     '--output', '-o',
     help='Specifies the Output format.',
     default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="uuid,name,type,proto,counters,description,updatefreq,content,enabled",
     show_default=True,
 )
@@ -81,13 +82,13 @@ def show(firewall_alias_svc: FirewallAliasFacade, **kwargs):
     '--output', '-o',
     help='Specifies the Output format.',
     default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="ip",
     show_default=True,
 )
@@ -153,14 +154,14 @@ def table(firewall_alias_svc: FirewallAliasFacade, **kwargs):
 @click.option(
     '--output', '-o',
     help='Specifies the Output format.',
-    default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    default="plain",
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="result,validations",
     show_default=True,
 )
@@ -250,14 +251,14 @@ def create(firewall_alias_svc: FirewallAliasFacade, **kwargs):
 @click.option(
     '--output', '-o',
     help='Specifies the Output format.',
-    default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    default="plain",
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="result,validations",
     show_default=True,
 )
@@ -288,14 +289,14 @@ def update(firewall_alias_svc: FirewallAliasFacade, **kwargs):
 @click.option(
     '--output', '-o',
     help='Specifies the Output format.',
-    default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    default="plain",
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="result,validations",
     show_default=True,
 )
