@@ -1,7 +1,7 @@
 import click
 
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
-from opnsense_cli.callbacks.click import formatter_from_formatter_name, bool_as_string, int_as_string
+from opnsense_cli.callbacks.click import formatter_from_formatter_name, bool_as_string, int_as_string, available_formats
 from opnsense_cli.commands.firewall import firewall
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.firewall import FirewallFilter
@@ -43,13 +43,13 @@ def rule(ctx, api_client: ApiClient, **kwargs):
     '--output', '-o',
     help='Specifies the Output format.',
     default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default=",".join([
         "uuid,sequence,interface,action,direction,ipprotocol,protocol",
         "source_net,source_port,destination_net,destination_port",
@@ -73,13 +73,13 @@ def list(firewall_rule_svc: FirewallRuleFacade, **kwargs):
     '--output', '-o',
     help='Specifies the Output format.',
     default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default=",".join([
         "sequence,action,quick,interface,direction,ipprotocol,protocol",
         "source_net,source_not,source_port,destination_net",
@@ -235,14 +235,14 @@ def show(firewall_rule_svc: FirewallRuleFacade, **kwargs):
 @click.option(
     '--output', '-o',
     help='Specifies the Output format.',
-    default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    default="plain",
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="result,validations",
     show_default=True,
 )
@@ -405,14 +405,14 @@ def create(firewall_rule_svc: FirewallRuleFacade, **kwargs):
 @click.option(
     '--output', '-o',
     help='Specifies the Output format.',
-    default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    default="plain",
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="result,validations",
     show_default=True,
 )
@@ -445,14 +445,14 @@ def update(firewall_rule_svc: FirewallRuleFacade, **kwargs):
 @click.option(
     '--output', '-o',
     help='Specifies the Output format.',
-    default="table",
-    type=click.Choice(['table', 'json', 'yaml']),
+    default="plain",
+    type=click.Choice(available_formats()),
     callback=formatter_from_formatter_name,
     show_default=True,
 )
 @click.option(
     '--cols', '-c',
-    help='Which columns should be printed?',
+    help='Which columns should be printed? Pass empty string (-c '') to show all columns',
     default="result,validations",
     show_default=True,
 )
